@@ -16,3 +16,11 @@ test_that("GLSZM Features are properly calculated", {
   expect_equal(glszm_LILAE(hbGLSZM), 5.67, tolerance = .02) 
   expect_equal(glszm_HILAE(hbGLSZM), 38, tolerance = .02)
 })
+
+test_that("GLSZM features are properly calculated", {
+  expect_equal(calc_features(glszm(hallbey, v=F)), read.csv("../csvs/glszm_features/hb.csv", stringsAsFactors=FALSE))
+  expect_equal(calc_features(glszm(tumor, v=F)), read.csv("../csvs/glszm_features/tumor.csv", stringsAsFactors=FALSE))
+  expect_equal(calc_features(glszm(noise, v=F)), read.csv("../csvs/glszm_features/noise.csv", stringsAsFactors=FALSE))
+  expect_equal(calc_features(glszm(bars, v=F)), read.csv("../csvs/glszm_features/bars.csv", stringsAsFactors=FALSE))
+  
+})
\ No newline at end of file
